==> jc-1.4.0.tar.gz: soot/relations/PhysicalDomain.h <==
// public class soot.relations.PhysicalDomain

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4a3ed72e61e8ab74 soot_relations_PhysicalDomain

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_PhysicalDomain_H_
#define _JC_soot_relations_PhysicalDomain_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_relations_PhysicalDomain$sub_refs	_jc_soot_relations_PhysicalDomain$sub_refs;
typedef struct _jc_soot_relations_PhysicalDomain$sub_nonrefs	_jc_soot_relations_PhysicalDomain$sub_nonrefs;
typedef struct _jc_soot_relations_PhysicalDomain$refs	_jc_soot_relations_PhysicalDomain$refs;
typedef struct _jc_soot_relations_PhysicalDomain$nonrefs	_jc_soot_relations_PhysicalDomain$nonrefs;
typedef struct _jc_soot_relations_PhysicalDomain$object	_jc_soot_relations_PhysicalDomain$object;

typedef const struct _jc_soot_relations_PhysicalDomain$vmethods	_jc_soot_relations_PhysicalDomain$vmethods;
typedef const struct _jc_soot_relations_PhysicalDomain$vtable	_jc_soot_relations_PhysicalDomain$vtable;
typedef const struct _jc_soot_relations_PhysicalDomain$vtype	_jc_soot_relations_PhysicalDomain$vtype;

// Constructors
extern void _jc_soot_relations_PhysicalDomain$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint);
extern void _jc_soot_relations_PhysicalDomain$method$_init$206934d97c5ba451(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_soot_relations_PhysicalDomain$method$bits$3e28f81bac6f9297(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
extern _jc_int_array *_jc_soot_relations_PhysicalDomain$method$getvars$6ae16cc02bef640a(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
extern jint _jc_soot_relations_PhysicalDomain$method$ithvar$9358077205c210bb(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_relations_PhysicalDomain$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
extern jint _jc_soot_relations_PhysicalDomain$method$var$e69a5ec020b7310b(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$bits$3e28f81bac6f9297;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$getvars$6ae16cc02bef640a;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$ithvar$9358077205c210bb;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$var$e69a5ec020b7310b;

// Static methods
extern void _jc_soot_relations_PhysicalDomain$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_soot_relations_PhysicalDomain$method$reverse$aab8bddef5ac8d63(_jc_env *, struct _jc_int_array *);
extern void _jc_soot_relations_PhysicalDomain$method$setOrder$b2177eb1631ed670(_jc_env *, struct _jc_object_array *, jboolean);

// Virtual methods structure
struct _jc_soot_relations_PhysicalDomain$vmethods {
	jint	(*bits$3e28f81bac6f9297)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
	_jc_int_array	*(*getvars$6ae16cc02bef640a)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
	jint	(*ithvar$9358077205c210bb)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
	jint	(*var$e69a5ec020b7310b)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *);
};

// Vtable
struct _jc_soot_relations_PhysicalDomain$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_PhysicalDomain$vmethods	soot_relations_PhysicalDomain;
};

// Vtype
struct _jc_soot_relations_PhysicalDomain$vtype {
	_jc_type			type;
	_jc_soot_relations_PhysicalDomain$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_PhysicalDomain$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_relations_PhysicalDomain$refs {
    _jc_soot_relations_PhysicalDomain$sub_refs	soot_relations_PhysicalDomain;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_PhysicalDomain$sub_nonrefs {
	jint	bits;
	jint	var;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_PhysicalDomain$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_PhysicalDomain$sub_nonrefs	soot_relations_PhysicalDomain;
};

// Object instance structure
struct _jc_soot_relations_PhysicalDomain$object {
	_jc_soot_relations_PhysicalDomain$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_PhysicalDomain$vtype	*vtype;
	_jc_soot_relations_PhysicalDomain$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_PhysicalDomain$vtype _jc_soot_relations_PhysicalDomain$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_PhysicalDomain, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_PhysicalDomain$class_object;

#endif	/* _JC_soot_relations_PhysicalDomain_H_ */

==> jc-1.4.6.tar.gz: soot/relations/PhysicalDomain.h <==
// public class soot.relations.PhysicalDomain

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4a3ed72e61e8ab74 soot_relations_PhysicalDomain

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_PhysicalDomain_H_
#define _JC_soot_relations_PhysicalDomain_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_relations_PhysicalDomain$sub_refs	_jc_soot_relations_PhysicalDomain$sub_refs;
typedef struct _jc_soot_relations_PhysicalDomain$sub_nonrefs	_jc_soot_relations_PhysicalDomain$sub_nonrefs;
typedef struct _jc_soot_relations_PhysicalDomain$refs	_jc_soot_relations_PhysicalDomain$refs;
typedef struct _jc_soot_relations_PhysicalDomain$nonrefs	_jc_soot_relations_PhysicalDomain$nonrefs;
typedef struct _jc_soot_relations_PhysicalDomain$object	_jc_soot_relations_PhysicalDomain$object;

typedef const struct _jc_soot_relations_PhysicalDomain$vmethods	_jc_soot_relations_PhysicalDomain$vmethods;
typedef const struct _jc_soot_relations_PhysicalDomain$vtable	_jc_soot_relations_PhysicalDomain$vtable;
typedef const struct _jc_soot_relations_PhysicalDomain$vtype	_jc_soot_relations_PhysicalDomain$vtype;

// Constructors
extern void _jc_soot_relations_PhysicalDomain$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_relations_PhysicalDomain$method$_init$206934d97c5ba451(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_relations_PhysicalDomain$method$bits$3e28f81bac6f9297(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
extern _jc_int_array *_jc_soot_relations_PhysicalDomain$method$getvars$6ae16cc02bef640a(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_relations_PhysicalDomain$method$ithvar$9358077205c210bb(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_relations_PhysicalDomain$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_relations_PhysicalDomain$method$var$e69a5ec020b7310b(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$bits$3e28f81bac6f9297;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$getvars$6ae16cc02bef640a;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$ithvar$9358077205c210bb;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_relations_PhysicalDomain$method_info$var$e69a5ec020b7310b;

// Static methods
extern void _jc_soot_relations_PhysicalDomain$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_soot_relations_PhysicalDomain$method$reverse$aab8bddef5ac8d63(_jc_env *, struct _jc_int_array *) _JC_JCNI_ATTR;
extern void _jc_soot_relations_PhysicalDomain$method$setOrder$b2177eb1631ed670(_jc_env *, struct _jc_object_array *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_relations_PhysicalDomain$vmethods {
	jint	(*bits$3e28f81bac6f9297)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
	_jc_int_array	*(*getvars$6ae16cc02bef640a)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
	jint	(*ithvar$9358077205c210bb)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
	jint	(*var$e69a5ec020b7310b)(_jc_env *, struct _jc_soot_relations_PhysicalDomain$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_relations_PhysicalDomain$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_PhysicalDomain$vmethods	soot_relations_PhysicalDomain;
};

// Vtype
struct _jc_soot_relations_PhysicalDomain$vtype {
	_jc_type			type;
	_jc_soot_relations_PhysicalDomain$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_PhysicalDomain$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_relations_PhysicalDomain$refs {
    _jc_soot_relations_PhysicalDomain$sub_refs	soot_relations_PhysicalDomain;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_PhysicalDomain$sub_nonrefs {
	jint	bits;
	jint	var;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_PhysicalDomain$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_PhysicalDomain$sub_nonrefs	soot_relations_PhysicalDomain;
};

// Object instance structure
struct _jc_soot_relations_PhysicalDomain$object {
	_jc_soot_relations_PhysicalDomain$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_PhysicalDomain$vtype	*vtype;
	_jc_soot_relations_PhysicalDomain$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_PhysicalDomain$vtype _jc_soot_relations_PhysicalDomain$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_PhysicalDomain, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_PhysicalDomain$class_object;

#endif	/* _JC_soot_relations_PhysicalDomain_H_ */
